@@ -1,10 +1,10 @@
 """Constants package for PyVSS."""
 PACKAGE_NAME = "pyvss"
 
-__version__ = '0.17.2'
+__version__ = '0.18.0'
 
 API_ENDPOINT_BASE = 'https://cloud-api.eis.utoronto.ca'
-VSKEY_STOR_ENDPOINT = 'https://vskey-stor.eis.utoronto.ca'
+VSS_API_WEBDAV_SERVER = 'https://vskey-stor.eis.utoronto.ca'
 DEFAULT_TIMEOUT = 60
 DEFAULT_DEBUG = False
 DEFAULT_DRY_RUN = False
@@ -15,7 +15,34 @@ VALID_VM_USAGE = [
     ('Development', 'Dev'),
     ('QA', 'QA'),
 ]
-VALID_VM_BUILD_PROCESS = ['clone', 'template', 'image', 'os_install']
+VALID_VM_BUILD_PROCESS = [
+    {
+        "description": "Empty virtual machine. OS must be installed.",
+        "label": "OS Install",
+        "type": "os_install",
+    },
+    {
+        "description": "Clone from either running or stopped virtual machine.",
+        "label": "VM Clone",
+        "type": "clone",
+    },
+    {
+        "description": "Deploy from virtual machine template.",
+        "label": "VM Template",
+        "type": "template",
+    },
+    {
+        "description": "Deploy from OVF/OVA virtual machine template.",
+        "label": "OVF/OVA Image",
+        "type": "image",
+    },
+    {
+        "description": "Deploy from content library "
+        "item (VM template or OVF).",
+        "label": "Content Library",
+        "type": "contentlib",
+    },
+]
 VALID_VM_NIC_TYPE = [
     {
         "description": "The VMXNET 3 adapter is the next generation of a "
